import {
  select,
  csv, 
  scaleLinear,
  max,
  extent,
  scaleBand,
  scalePoint,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

    // d.mpg = +d.mpg;
    // d.cylinders = +d.cylinders;
    // d.displacement = +d.displacement;
    // d.horsepower = +d.horsepower;
    // d.weight = +d.weight;
    // d.acceleration = +d.acceleration;
    // d.year = +d.year;

const render = data => {
  const xAxisLabel = 'Weight';
  const xValue = d => d.weight;
  const yAxisLabel = 'Acceleration';
  const yValue = d => d.acceleration;
  const circle_radius = 10;

  const margin = { top: 40, right: 40, bottom: 80, left: 100};
  const innerwidth = width - margin.left -margin.right;
  const innerheight = height - margin.top -margin.bottom;
  
  const xScale = scaleLinear()
    .domain(extent(data,xValue))
    .range([0, innerwidth])
    .nice();
  
  //const Axis = axisLeft(yScale);
  
  const yScale = scaleLinear()
    .domain(extent(data,yValue))
    .range([0,innerheight])
    .nice(); 
  
  const g = svg.append('g')
    .attr('transform',`translate(${margin.left},${margin.top})`);
  
  const xAxisTickFormat = number => format('.3s')(number)
       .replace('G','B');
  const xAxis = axisBottom(xScale).tickFormat(xAxisTickFormat).tickSize(-innerheight).tickPadding(15);
  const yAxis = axisLeft(yScale).tickSize(-innerwidth);
  
  g.append('g')
     .call(yAxis);
  
  const xAxisG = g.append('g')
    .call(xAxis)
    .attr('transform', `translate(0, ${innerheight})`);
  
  const yAxisG = g.append('g').call(yAxis);
    
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class','axis-label')
      .attr('y',60).attr('x',innerwidth/2)
      .attr('fill','black')
      .text(xAxisLabel);
  
  yAxisG.append('text')
      .attr('class','axis-label')
      .attr('y',-50)
      .attr('x',-innerHeight/2 +50)
      .attr('fill','black')
      .attr('transform', `rotate(-90)`) 
      .attr('text-anchor','middle')
      .text(yAxisLabel);

  
  g.selectAll('circle').data(data)
    .enter().append('circle')
      .attr('cy', d => yScale(yValue(d)) )
      .attr('cx', d => xScale(xValue(d)) )
      .attr('r', circle_radius);  
  
  g.append('text')
      .attr('class','title')
      .attr('y',-5).attr('x',100)
      .text('Cars: Acceleration v.s. Weight');
  
};



csv('https://vizhub.com/curran/datasets/auto-mpg.csv')
  .then(data => {
	data.forEach( d=>{
    d.mpg = +d.mpg;
    d.cylinders = +d.cylinders;
    d.displacement = +d.displacement;
    d.horsepower = +d.horsepower;
    d.weight = +d.weight;
    d.acceleration = +d.acceleration;
    d.year = +d.year;
  });  
  render(data);
});